<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\Controller\CrudWithParameterBag;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request\Row;
use Teknisa\MAN\Utilities\Util;
use Teknisa\MAN\Services;
use Teknisa\MAN\Services\ParamTAAService as ParamTAAService;

class ParamTAA extends CrudWithParameterBag {
    
    protected $parameterBagColumns = array('NRORG','CDFILIAL'); 
    protected $parameterColumns = array('CDFILIAL', 'CDCAIXA', 'TPMIDIATAA', 'LAYOUTMIDIA', 'NRORG', 'TMPDURACAO', 'CDPRODUTO', 'MIDIAURLTAA');
    
    protected $crudService;
    protected $dataSourceName = "orm00029_paramTAA";

    
    public function __construct(ParameterBag $parameterBag, Manager $dataSourceManager, Util $utilService, ParamTAAService $service, Services\FileUploaderService $fileUploaderService, $crudService) {
        parent::__construct($dataSourceManager, $parameterBag);  
        $this->utilService  = $utilService;
        $this->ParamTAAService = $service;
        $this->fileUploaderService = $fileUploaderService;
        $this->crudService = $crudService;
    }
    
    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = "orm00029_paramTAA";
        
        if($request->getFilterCriteria()->getConditions()[0]['columnName'] !== "id") 
            parent::find($request,$response);
    }
    
    public function findCheckedRows(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = "orm00029_paramTAA";
        
        if($request->getFilterCriteria()->getConditions()[0]['columnName'] !== "id") 
            parent::find($request,$response);
    }
    
    public function save(DTO\Request\DataSet $request, DTO\Response $response) {
        $rows = $request->getDataSet()->getRows();
        $row = $rows[0];
        $this->fileUploaderService->setImageForSave($row, 'MIDIAURLTAA', 'MIDIAURLTAA');
        $this->dataSourceName = "orm00029_paramTAA";
        $params = $this->utilService->getParamsAsArray($request);
        
        $params = $params[0];
        
        try {
            if($params['__is_new'])
                $retorno = $this->ParamTAAService->saveMidias($params);
            else 
                $retorno = $this->ParamTAAService->updateMidias($params);
                
            $response->addDataset(new DataSet($this->dataSourceName,array('response' => $retorno)));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
    
    public function deleteMidias(Row $request, DTO\Response $response) {
        $this->dataSourceName = "orm00029_paramTAA";

        try {
            $request = $this->crudService->buildDataSetIfRow($request, $this->dataSourceName);
            $dataSet = $request->getDataSet();
            $dataSet->setDataSourceName($this->dataSourceName);
            $deletedRows = $this->dataSourceManager->delete($dataSet);
            $response->addDataSet(new DataSet($this->dataSourceName, $deletedRows));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
}